@@ -41,10 +41,17 @@ class Network3Medusa():
             if WEBEX_ROOM:
                 self.send_webex_notification()
         elif self.command == "show running-config":
+            first = True
             for line in raw_json.split('\n'):
-                print("new")
-                print(line)
-
+                if first:
+                    first = False
+                    raw_json=line
+                    self.add_file_to_hedera(line)
+                else:
+                    self.append_file_to_hedera(line)
+            query = FileInfoQuery().setFileId(self.fileId)
+            info = query.execute(self.client)
+            print("File size according to `FileInfoQuery`: ", info.size)
         else:
             self.add_file_to_hedera(raw_json)
             if WEBEX_ROOM:
